@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -26,10 +26,10 @@ class DatetimeEditor(EditorFactory):
     # -------------------------------------------------------------------------
 
     #: The earliest datetime allowed by the editor
-    minimum_datetime = Datetime(datetime.datetime(100, 1, 1))
+    minimum_datetime = Datetime(datetime.datetime(100, 1, 1), allow_none=True)
 
     #: The latest datetime allowed by the editor
-    maximum_datetime = Datetime(datetime.datetime.max)
+    maximum_datetime = Datetime(datetime.datetime.max, allow_none=True)
 
     # -- ReadonlyEditor traits ------------------------------------------------
 
